Index: third_party/WebKit/Source/modules/payments/PaymentsValidators.h |
diff --git a/third_party/WebKit/Source/modules/payments/PaymentsValidators.h b/third_party/WebKit/Source/modules/payments/PaymentsValidators.h |
index 672f3bed58bb9599cedd10c4a9d275bbba7a281d..5d8ca7afa5f06c9cba28bf7d110eabcddde23bfa 100644 |
--- a/third_party/WebKit/Source/modules/payments/PaymentsValidators.h |
+++ b/third_party/WebKit/Source/modules/payments/PaymentsValidators.h |
@@ -31,12 +31,12 @@ public: |
// Returns true if |code| is a valid ISO 15924 script code. |
static bool isValidScriptCodeFormat(const String& code, String* optionalErrorMessage); |
// Returns true if the shipping address is valid: |
// - Has a valid region code |
// - Has a valid language code, if any. |
// - Has a valid script code, if any. |
// A script code should be present only if language code is present. |
- static bool isValidShippingAddress(const mojom::blink::ShippingAddressPtr&, String* optionalErrorMessage); |
+ static bool isValidShippingAddress(const mojom::blink::PaymentAddressPtr&, String* optionalErrorMessage); |
}; |
} // namespace blink |
@@ -31,12 +31,12 @@ public: |
// Returns true if |code| is a valid ISO 15924 script code. |
static bool isValidScriptCodeFormat(const String& code, String* optionalErrorMessage); |
- // Returns true if the shipping address is valid: |
+ // Returns true if the payment address is valid: |
// - Has a valid region code |
// - Has a valid language code, if any. |